@@ -10,6 +10,13 @@ import HSH
 {- | Run each test three times in an attempt to check for race conditions
 or nondeterministic behavior.  Not perfect, but it could help anyhow. -}
 
+testcmd expected cmd =
+    [tc "run1", tc "run2", tc "run3"]
+    where tc runno = TestLabel runno $ TestCase $ do
+                       r <- run cmd
+                       assertEqual "run result" expected r
+
+{-
 testcmd expected cmd =
     do r <- run cmd
        r2 <- run cmd
@@ -17,5 +24,6 @@ testcmd expected cmd =
        assertEqual "expected" expected r
        assertEqual "run 2" expected r2
        assertEqual "run 3" expected r3
+-}
 
-cmdcase name expected cmd = TestLabel name $ TestCase (testcmd expected cmd)
+cmdcase name expected cmd = TestLabel name $ TestList (testcmd expected cmd)
